@@ -12,10 +12,8 @@ use imagequant::capi::*;
 use imagequant::Error::LIQ_OK;
 use imagequant::*;
 use std::ffi::CString;
-use std::mem::ManuallyDrop;
-use std::mem::MaybeUninit;
-use std::os::raw::c_char;
-use std::os::raw::{c_int, c_uint, c_void};
+use std::mem::{ManuallyDrop, MaybeUninit};
+use std::os::raw::{c_char, c_int, c_uint, c_void};
 use std::ptr;
 
 pub use imagequant::Error as liq_error;
@@ -528,7 +526,7 @@ pub extern "C" fn liq_image_quantize(img: &mut liq_image, attr: &mut liq_attr, w
 
 #[no_mangle]
 #[inline(never)]
-pub fn liq_histogram_quantize(hist: &mut liq_histogram, attr: &liq_attr, write_only_output: &mut MaybeUninit<Option<Box<liq_result>>>) -> liq_error {
+pub extern "C" fn liq_histogram_quantize(hist: &mut liq_histogram, attr: &liq_attr, write_only_output: &mut MaybeUninit<Option<Box<liq_result>>>) -> liq_error {
     if bad_object!(attr, LIQ_ATTR_MAGIC) ||
        bad_object!(hist, LIQ_HISTOGRAM_MAGIC) { return Error::InvalidPointer; }
     let attr = &attr.inner;
